import { BrowserPlugin } from '@snowplow/browser-tracker-core';
import { CommonEventProperties, SiteSearchEvent, SocialInteractionEvent } from '@snowplow/tracker-core';
declare function SiteTrackingPlugin(): BrowserPlugin;
/**
 * Track a social interaction event
 *
 * @param event - The event information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function trackSocialInteraction(event: SocialInteractionEvent & CommonEventProperties, trackers?: Array<string>): void;
/**
 * Track an internal search event
 *
 * @param event - The event information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function trackSiteSearch(event: SiteSearchEvent & CommonEventProperties, trackers?: Array<string>): void;
/** A Timing Event */
interface TimingEvent {
    /** Category of the timing event */
    category: string;
    /** The variable being timed */
    variable: string;
    /** The timing result */
    timing: number;
    /** An additional label */
    label?: string;
}
/**
 * Track a timing event (such as the time taken for a resource to load)
 *
 * @param event - The event information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function trackTiming(event: TimingEvent & CommonEventProperties, trackers?: Array<string>): void;
export { SocialInteractionEvent, SiteSearchEvent, SiteTrackingPlugin, trackSocialInteraction, trackSiteSearch, TimingEvent, trackTiming };
